@@ -21,16 +21,17 @@
 #include <qmap.h>
 #include <qptrlist.h>
 #include <qwidget.h>
+#include <qvbox.h>
 #include <kdialogbase.h>
 
+class Barkode;
+class KColorButton;
 class KComboBox;
 class KDoubleNumInput;
 class KIntNumInput;
 class QCheckBox;
 class QRadioButton;
 
-struct barcodeData;
-
 /** A base class for all widgets, that will be used in AdvancedBarcodeDialog
   * to modify the settings of a barcode. The API is simple. You can only set the
   * current barcode settings and retrieve them after the user modified them.
@@ -39,8 +40,8 @@ struct barcodeData;
   */
 class BarcodeDlgBase {
     public:
-        virtual void setData( const barcodeData* b ) = 0;
-        virtual void getData( barcodeData* b ) const = 0;
+        virtual void setData( Barkode* b ) = 0;
+        virtual void getData( Barkode* b ) const = 0;
 };
 
 /**
@@ -59,8 +60,8 @@ class AdvancedBarcodeDialog : public KDialogBase {
         AdvancedBarcodeDialog( QString type, QWidget* parent = 0, const char* name = 0 );
         ~AdvancedBarcodeDialog();
 
-        void setData( const barcodeData* b );
-        void getData( barcodeData* b );
+        void setData( Barkode* b );
+        void getData( Barkode* b );
 
     private:
         QPtrList<BarcodeDlgBase> list;
@@ -74,11 +75,12 @@ class TBarcodeDlg : public QWidget, public BarcodeDlgBase {
     public: 
         TBarcodeDlg(QWidget *parent=0, const char *name=0);
 
-        void setData( const barcodeData* b );
-        void getData( barcodeData* b ) const;
+        void setData( Barkode* b );
+        void getData( Barkode* b ) const;
 
     private:
         KDoubleNumInput* spinModule;
+        KIntNumInput* spinHeight;
         QCheckBox* checkEscape;
         QCheckBox* checkAbove;
         QCheckBox* checkAutoCorrect;
@@ -95,8 +97,8 @@ class PDF417BarcodeDlg : public QWidget, public BarcodeDlgBase {
     public:
         PDF417BarcodeDlg(QWidget *parent=0, const char *name=0);
 
-        void setData( const barcodeData* b );
-        void getData( barcodeData* b ) const;
+        void setData( Barkode* b );
+        void getData( Barkode* b ) const;
         
     private:
         KIntNumInput* spinRow;
@@ -112,8 +114,8 @@ class DataMatrixDlg : public QWidget, public BarcodeDlgBase {
     public:
         DataMatrixDlg(QWidget *parent=0, const char *name=0);
 
-        void setData( const barcodeData* b );
-        void getData( barcodeData* b ) const;
+        void setData( Barkode* b );
+        void getData( Barkode* b ) const;
         
     private:
         KComboBox* comboDataMatrix;
@@ -123,12 +125,12 @@ class DataMatrixDlg : public QWidget, public BarcodeDlgBase {
   * @author Dominik Seichter
   */
 class SequenceDlg : public QWidget, public BarcodeDlgBase {
-   Q_OBJECT
+    Q_OBJECT
     public:
         SequenceDlg(QWidget *parent=0, const char *name=0);
 
-        void setData( const barcodeData* b );
-        void getData( barcodeData* b ) const;
+        void setData( Barkode* b );
+        void getData( Barkode* b ) const;
 
     private slots:
         void enableControls();
@@ -143,4 +145,36 @@ class SequenceDlg : public QWidget, public BarcodeDlgBase {
         KIntNumInput* spinStart;
 };
 
+/** A configuration widget for colors in pure postscript barcodes
+  * @author Dominik Seichter
+  */
+class ColorDlg : public QVBox, public BarcodeDlgBase {
+    Q_OBJECT
+    public:
+        ColorDlg(QWidget *parent=0, const char *name=0);
+
+        void setData( Barkode* b );
+        void getData( Barkode* b ) const;
+
+    private:
+        KColorButton* buttonBarColor;
+        KColorButton* buttonBackColor;
+        KColorButton* buttonTextColor;
+};
+
+/** A configuration widget for colors in pure postscript barcodes
+  * @author Dominik Seichter
+  */
+class PurePostscriptDlg : public QVBox, public BarcodeDlgBase {
+    Q_OBJECT
+    public:
+        PurePostscriptDlg(QWidget *parent=0, const char *name=0);
+
+        void setData( Barkode* b );
+        void getData( Barkode* b ) const;
+
+    private:
+        QCheckBox* checkChecksum;
+};
+
 #endif
