@@ -33,6 +33,7 @@
 #include <qdialog.h>
 #include <qmap.h>
 
+class BatchPrinter;
 class KURL;
 class KAction;
 class KActionMenu;
@@ -49,9 +50,8 @@ class KCommandHistory;
 class MyCanvasText;
 class MyCanvasRectangle;
 class MyCanvasView;
-class CanvasBarcode;
+class BarcodeItem;
 class MyCanvas;
-class QCanvasItem;
 class QCanvasItemList;
 class QCheckBox;
 class KComboBox;
@@ -68,6 +68,12 @@ class QPaintDevice;
 class QString;
 class KPushButton;
 class KPrinter;
+class QCanvasItem;
+class TCanvasItem;
+class RectItem;
+class LineItem;
+
+class TokenProvider;
 /** The LabelEditor is a graphical, easy to use label designer.
   * It provides all the function necessary to create colorful labels
   * and save them. Labels can also be printed directly, but without database
@@ -76,15 +82,15 @@ class KPrinter;
 class LabelEditor : public DSMainWindow, public EditorIface, private LabelUtils, private XMLUtils {
     Q_OBJECT
     public:
-        enum _mode {
-            CreateNewLabel,
-            LoadLabel
+        enum ELabelEditorMode {
+            eCreateNewLabel,
+            eLoadLabel
         };
 
         LabelEditor( QWidget *parent=0, QString _filename = QString::null,
             const char *name="labeleditor", WFlags f = WType_TopLevel | WDestructiveClose );
         ~LabelEditor();
-        bool startupDlg( int mode, QString f = QString::null );
+        bool startupDlg( ELabelEditorMode mode, QString f = QString::null );
 
         /**
           * returns the filename of the currently loaded label.
@@ -93,15 +99,35 @@ class LabelEditor : public DSMainWindow, public EditorIface, private LabelUtils,
         
     public slots:
         void print();
+        void printBCP();
+        void printImage();
+        
     private:
+
+	/** Creates a KCommandHistory object which will be 
+	 *  pointed to by history.
+	 *  Make sure to delete history by yourself when needed.
+	 */
+	void createCommandHistory();
+	/** Create undo and redo actions and plug them into
+	 *  menus and toolbars. They have to be regenerated
+	 *  when ever createCommandHistory was called.
+	 */
+	void createCommandHistoryActions();
+
         QString getCustomerName( int mode = 0, QString text = "" );
         void clearLabel();
-        void setupBarcode( CanvasBarcode* bcode );
+        //void setupBarcode( BarcodeItem* bcode );
         void insertText( QString caption );
+        //NY35
+        void insertTextLine( QString caption );
+        //NY35
         void setupActions();
         void enableActions();
         bool isChanged();   // if the current document has been changed
-
+        void batchPrint( BatchPrinter* batch, int copies, int mode );
+        void setupContextMenu();
+        
     private slots:
         void startEditor();
         bool open();
@@ -113,27 +139,21 @@ class LabelEditor : public DSMainWindow, public EditorIface, private LabelUtils,
         bool newLabel();
         void insertBarcode();
         void insertPicture();
-        void insertPicture( QImage* img );
         void insertText();
-        void insertDataText( int index );
+        void insertDataText();
+        //NY36
+        void insertTextLine();
+        //NY36
         void insertRect();
         void insertCircle();
         void insertLine();
-        void insertAddress();
-        void exportLabel();
 
-        /** export to the Zebra Printing Language */
-        void exportZPL();
         void changeDes();
         void changeSize();
         void updateInfo();
-        void doubleClickedItem( QCanvasItem* item );
-        void showContextMenu( QCanvasItem* item, QPoint pos );
+        void doubleClickedItem( TCanvasItem* item );
+        void showContextMenu( QPoint pos );
         void doubleClickedCurrent();
-        void changePictureSettings( QCanvasItem* item = 0 );
-        void changeText( QCanvasItem* item = 0 );
-        void changeRectSettings( QCanvasItem* item = 0 );
-        void changeLineSettings( QCanvasItem* item = 0 );
         void spellCheck();
         void centerVertical();
         void centerHorizontal();
@@ -143,7 +163,6 @@ class LabelEditor : public DSMainWindow, public EditorIface, private LabelUtils,
         void backCurrent();
         void preview();
         void toggleGrid();
-        void moveByValue();
         void cut();
         void copy();
         void paste();
@@ -156,8 +175,8 @@ class LabelEditor : public DSMainWindow, public EditorIface, private LabelUtils,
         void closeLabel();
         void setEdited();
         void launchAddressBook();
-        void enableControls();
-
+        void lockItem();
+        
     protected:
         void closeEvent( QCloseEvent* e );
 
@@ -166,9 +185,10 @@ class LabelEditor : public DSMainWindow, public EditorIface, private LabelUtils,
         KAction* saveAct;
         KAction* saveAsAct;
         KAction* exportAct;
-        KAction* exportZPLAct;
         KAction* descriptionAct;
         KAction* printAct;
+        KAction* bcpAct;
+        KAction* imgAct;
         KAction* changeSizeAct;
         KAction* deleteAct;
         KAction* editPropAct;
@@ -179,6 +199,8 @@ class LabelEditor : public DSMainWindow, public EditorIface, private LabelUtils,
         KAction* pictureAct;
         KAction* previewAct;
         KAction* textAct;
+        KAction* textDataAct;
+        KAction* textLineAct;
         KAction* spellAct;
         KAction* cutAct;
         KAction* copyAct;
@@ -186,12 +208,16 @@ class LabelEditor : public DSMainWindow, public EditorIface, private LabelUtils,
         KAction* undoAct;
         KAction* redoAct;
         KAction* closeLabelAct;
-        KAction* addressAct;
         KAction* addressBookAct;
+        KAction* selectAllAct;
+        KAction* deSelectAllAct;
 
-        KPopupMenu* exportMenu;
-        KActionMenu* menuFields;
-        KActionMenu* menuSystemFields;
+	/**
+	 * Undo/Redo actins get pluged into this menu
+	 */
+	KPopupMenu* editMenu;        
+        KPopupMenu* exportMenu;        
+        KPopupMenu* m_mnuContext;
         
         KToolBar* tools;
         
@@ -206,7 +232,8 @@ class LabelEditor : public DSMainWindow, public EditorIface, private LabelUtils,
         MyCanvasView* cv;
 
         Definition* d;
-                
+	TokenProvider* m_token;
+
         // Label info's:
         QString description;    // description
         QString filename;       // current file
@@ -221,57 +248,4 @@ class LabelEditor : public DSMainWindow, public EditorIface, private LabelUtils,
         bool m_edited;
 };
 
-class BarcodeCombo;
-class BarcodeWidget;
-class KLineEdit;
-class KIntNumInput;
-class KColorButton;
-class QCheckBox;
-
-/** Change barcode settings from within the labeleditor. The difference
-  * to BarCodeDialog is that there is no preview, but SQL Database support.
-  *
-  * @see BarCodeDialog
-  * @author Dominik Seichter
-  */
-class BarcodeSettingsDlg : public KDialogBase {
-    Q_OBJECT
-
-    public:
-        BarcodeSettingsDlg( QWidget* parent = 0, const char* name = 0 );
-        ~BarcodeSettingsDlg();
-
-        KComboBox* comboComplex;
-        BarcodeWidget* barcode;
-        
-    public slots:
-        void changedCombo();
-        
-    private slots:
-        void defaults();
-        
-    protected:
-        QLabel* TextLabel1;
-
-        QVBoxLayout* BarcodeSettingsLayout;
-};
-
-class PictureSettings : public KDialogBase {
-    Q_OBJECT
-    public:
-        PictureSettings( QWidget* parent = 0, const char* name = 0 );
-        ~PictureSettings() { }
-
-        KIntNumInput* spinRotation;
-};
-
-class PositionDialog : public KDialogBase {
-    Q_OBJECT
-    public:
-        PositionDialog( QWidget* parent = 0, const char* name = 0 );
-        ~PositionDialog() { }
-
-        KIntNumInput* spinX;
-        KIntNumInput* spinY;
-};
 #endif
