@@ -33,19 +33,22 @@
 // own includes
 #include "printersettings.h"
 
+#define CONVERSION_FACTOR 25.4000508001016
+
 LabelUtils::LabelUtils()
 {
 }
 
 LabelUtils::~LabelUtils()
 { }
+
 double LabelUtils::pixelToMm( double pixel, const QPaintDevice* device, int mode )
 {
-    QPaintDeviceMetrics pdm( device );
+    QPaintDeviceMetrics pdm( device ? device : KApplication::desktop() );
     if( mode == DpiX )
-        return (pixel * 25.4) / pdm.logicalDpiX();
+	return (pixel * CONVERSION_FACTOR) / (double)pdm.logicalDpiX();
     else
-        return (pixel * 25.4) / pdm.logicalDpiY();
+	return (pixel * CONVERSION_FACTOR) / (double)pdm.logicalDpiY();
 }
 
 double LabelUtils::mmToPixel( double mm, const QPaintDevice* device, int mode )
@@ -53,11 +56,17 @@ double LabelUtils::mmToPixel( double mm, const QPaintDevice* device, int mode )
     if( !mm )
         return 0;
 
-    QPaintDeviceMetrics pdm( device );
+    // We don't get valid metrics from the printer - and we want a better resolution
+    // anyway (it's the PS driver that takes care of the printer resolution).
+
+    QPaintDeviceMetrics pdm( device ? device : KApplication::desktop() );
+    
+//    qDebug("DpiX=%i", pdm.logicalDpiX());
+//    qDebug("DpiY=%i", pdm.logicalDpiY());
     if( mode == DpiX )
-        return (mm / 25.4) * pdm.logicalDpiX();
+	return (mm / CONVERSION_FACTOR) * (double)pdm.logicalDpiX();
     else
-        return (mm / 25.4) * pdm.logicalDpiY();
+	return (mm / CONVERSION_FACTOR) * (double)pdm.logicalDpiY();
 }
 
 double LabelUtils::pixelToPixelX( double unit, const QPaintDevice* src, const QPaintDevice* dest )
@@ -65,7 +74,7 @@ double LabelUtils::pixelToPixelX( double unit, const QPaintDevice* src, const QP
     QPaintDeviceMetrics p1( src );
     QPaintDeviceMetrics p2( dest );
 
-    return ( unit * p2.logicalDpiX() ) / p1.logicalDpiX();
+    return ( unit * (double)p2.logicalDpiX() ) / (double)p1.logicalDpiX();
 }
 
 double LabelUtils::pixelToPixelY( double unit, const QPaintDevice* src, const QPaintDevice* dest )
@@ -73,7 +82,8 @@ double LabelUtils::pixelToPixelY( double unit, const QPaintDevice* src, const QP
     QPaintDeviceMetrics p1( src );
     QPaintDeviceMetrics p2( dest );
 
-    return ( unit * p2.logicalDpiY() ) / p1.logicalDpiY();
+    //return pixelToPixelX( unit, src, dest );
+    return ( unit * (double)p2.logicalDpiY() ) / (double)p1.logicalDpiY();
 }
 
 const QString LabelUtils::getTypeFromCaption( const QString & cap )
@@ -98,32 +108,20 @@ QSize LabelUtils::stringSize( const QString & t )
     return s;
 }
 
-void LabelUtils::renderString( QPainter* painter, const QString & t, int w, int h, double scalex, double scaley )
+void LabelUtils::renderString( QPainter* painter, const QString & t, const QRect & rect, double scalex, double scaley )
 {
     // DSRichText cannot calculate the width on its own
-    QSimpleRichText srt( t, painter->font() );
-    int width = (w > 0) ? w : srt.widthUsed();
-    int height = (h > 0) ? h : srt.height();
-
-#ifdef QT_TEXT_BUG
+    QSimpleRichText srt( t, KApplication::font() );
+    int width = (rect.width() > 0) ? rect.width() : srt.widthUsed();
+    int height = (rect.height() > 0) ? rect.height() : srt.height();
     
     DSRichText r( t );
+    r.setX( rect.x() );
+    r.setY( rect.y() );
     r.setWidth( width );
     r.setHeight( height );
     r.setScale( scalex, scaley );
-    r.draw( painter );
-    
-#else
-srt.setWidth( width );
-//    srt.setWidth( painter, width );
-
-    QRect r( 0, 0, width, height );
-
-    painter->setPen( Qt::black );
-    QColorGroup cg;
-    
-    srt.draw( painter, 0, 0, r, cg );
-#endif
+    r.draw( painter );    
 }
 
 QPixmap* LabelUtils::drawString( const QString & t, int w, int h, double rot )
