@@ -19,6 +19,7 @@
 #define PREVIEWDIALOG_H
 
 #include <qdialog.h>
+#include <kabc/addressee.h>
 
 class Definition;
 class KComboBox;
@@ -39,6 +40,7 @@ class PreviewDialog : public QDialog  {
         void customerNameChanged( int index );
         void customerIdChanged( int index );
         void setupSql();
+        void selectAddress();
 
     private:
         QLabel* preview;
@@ -46,6 +48,7 @@ class PreviewDialog : public QDialog  {
         KLineEdit* articleId;
         KLineEdit* groupName;
         KLineEdit* serialStart;
+        KLineEdit* lineAddr;
 
         KIntNumInput* spinIndex;
         KIntNumInput* serialInc;
@@ -55,6 +58,9 @@ class PreviewDialog : public QDialog  {
         
         KPushButton* buttonUpdate;
         KPushButton* buttonClose;
+        KPushButton* buttonAddr;
+
+        KABC::Addressee m_address;
 
         Definition* def;
         QIODevice* file;
@@ -65,7 +71,6 @@ class PreviewDialog : public QDialog  {
         static int m_index;
         static QString group;
         static QString article;
-        
 };
 
 #endif
