@@ -140,8 +140,9 @@ bool SqlTables::newTables( const QString & username, const QString & password, c
                           QString( TABLE_BASIC "', '" TABLE_CUSTOMER "', '"
                           TABLE_CUSTOMER_TEXT) +i18n("' and '") + QString(TABLE_LABEL_DEF "'")) ==  KMessageBox::Cancel )
         return false;
-	if( !drivers[driver] )
-			return false;
+
+    if( !drivers[driver] )
+        return false;
 	
     QSqlDatabase*dbase = QSqlDatabase::addDatabase(driver, drivers[driver]->initdb( database ) );
     dbase->setDatabaseName( drivers[driver]->initdb( database ) );
@@ -434,6 +435,25 @@ bool SqlTables::testSettings( const QString & username, const QString & password
     QSqlDatabase* db = QSqlDatabase::addDatabase( driver );
     if( !drivers[driver] )
       return false;
+
+    db->setDatabaseName( database );
+    db->setUserName( username );
+    db->setPassword( password );
+    db->setHostName( hostname );
+
+    if( !db->open() ) 
+    {
+        QSqlDatabase::removeDatabase( database );
+    }
+    else 
+    {
+        KMessageBox::information( 0, i18n("Connected successfully to your database") );
+        db->close();
+        QSqlDatabase::removeDatabase( database );
+        return true;
+    }
+
+    db = QSqlDatabase::addDatabase( driver );
     
     db->setDatabaseName( drivers[driver]->initdb( database ) );
 
