@@ -49,6 +49,16 @@ typedef struct mysqldata {
     QString database;   // kbarcode
     QString driver;     // QMYSQL3
     bool autoconnect;
+
+    void operator=( const mysqldata & rhs ) {
+        username = rhs.username;
+        password = rhs.password;
+        hostname = rhs.hostname;
+        database = rhs.database;
+        driver   = rhs.driver;
+
+        autoconnect = rhs.autoconnect;        
+    }
 };
 
 
@@ -86,18 +96,21 @@ class QSqlQuery;
 class SqlTables : public QObject {
     Q_OBJECT
     public:
-        SqlTables( QObject* parent = 0 );
-        ~SqlTables();
-
         /** get a mysqldata object which contains the current database settings.
           * this object is for all sql databases, not only for mysql. The name is just a
           * relict from the past ;-)
           * @return mysqldata*
           */
-        mysqldata* getData() const {
+        const mysqldata & getData() const {
             return sqldata;
         }
 
+        /** Set the database settings
+         */
+        void setData( const mysqldata & data ) {
+            sqldata = data;
+        }
+    
         /** get an instance of this singleton class. Always use this method as there is
           * no public constructor.
           * @return SqlTables*
@@ -112,7 +125,10 @@ class SqlTables : public QObject {
         }
 
         const SqlDescription* driver() const;
+
     public slots:
+        const QString getBarcodeMaxLength( const QString & name );
+        
         void loadConfig();
         void saveConfig();
 
@@ -129,22 +145,32 @@ class SqlTables : public QObject {
         void importData( const QString & filename, QSqlDatabase* db );
         bool testSettings( const QString & username, const QString & password, const QString & hostname, const QString & database, const QString & driver );
 
+	inline QSqlDatabase* database() const;
+
     signals:
         void tablesChanged();
         void connectedSQL();
 
     private:
+        SqlTables( QObject* parent = 0 );
+        ~SqlTables();
+
         void exec( QSqlQuery* query, const QString & text );
         void updateTables();
         
         bool connected;
 
         QSqlDatabase* db;
-        mysqldata* sqldata;
+        mysqldata sqldata;
 
         static SqlTables* instance;
 };
 
+inline QSqlDatabase* SqlTables::database() const
+{
+    return db;
+}
+
 class KComboBox;
 class KLineEdit;
 class KPushButton;
